..
   haggis: a library of general purpose utilities
..
   Copyright (C) 2023  Joseph R. Fox-Rabinovitz <jfoxrabinovitz at gmail dot com>
..
   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU Affero General Public License as
   published by the Free Software Foundation, either version 3 of the
   License, or (at your option) any later version.
..
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU Affero General Public License for more details.
..
   You should have received a copy of the GNU Affero General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
..
   Author: Joseph Fox-Rabinovitz <jfoxrabinovitz at gmail dot com>
   Version: 13 Apr 2019: Initial Coding

.. _index:

==================================
Welcome to Haggis's documentation!
==================================

Haggis is a utility library. It consists of a number of disjoint modules, some
of which require optional dependencies to enable.

.. toctree::
   :maxdepth: 2
   :caption: Contents:
   :name: index-toc

   installation
   api


==================
Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
* :doc:`todos`

Project home page: https://github.com/madphysicist/haggis
